@@ -10,11 +10,9 @@ from sdmxthon.model.base import MaintainableArtefact, NameableArtefact, \
 from sdmxthon.model.header import Contact
 from sdmxthon.model.representation import Representation
 from sdmxthon.model.utils import generic_setter, bool_setter
-from sdmxthon.parsers.references import RelationshipRefType
 from sdmxthon.utils.handlers import add_indent, export_intern_data, \
     split_unique_id
 from sdmxthon.utils.mappings import structureAbbr
-from sdmxthon.utils.xml_base import find_attr_value_
 
 
 class ItemScheme(MaintainableArtefact):
@@ -52,10 +50,10 @@ class ItemScheme(MaintainableArtefact):
         if items is not None:
             urn_list = []
             for i in items:
-                if i.urn not in urn_list:
+                if i.urn is not None and i.urn not in urn_list:
                     urn_list.append(i.urn)
                     self.append(i)
-                else:
+                elif i.urn is not None:
                     raise ValueError(
                         'Item Scheme cannot have two items with same URN')
 
@@ -63,8 +61,7 @@ class ItemScheme(MaintainableArtefact):
         if isinstance(other, ItemScheme):
             return super(ItemScheme, self).__eq__(
                 other) and self._items == other._items
-        else:
-            return False
+        return False
 
     def __str__(self):
         return f'<{self.__class__.__name__} - {self.unique_id}>'
@@ -108,23 +105,6 @@ class ItemScheme(MaintainableArtefact):
             raise TypeError(
                 f"The object has to be of the type {self._itemType}")
 
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        super(ItemScheme, self)._build_attributes(node, attrs,
-                                                  already_processed)
-
-        value = find_attr_value_('isPartial', node)
-        if value is not None and 'isPartial' not in already_processed:
-            already_processed.add('isPartial')
-            value = self._gds_parse_boolean(value)
-            self.is_partial = value
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=None,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        super(ItemScheme, self)._build_children(child_, node, nodeName_,
-                                                fromsubclass_, gds_collector_)
-
     def _parse_XML(self, indent, label):
         prettyprint = indent != ''
 
@@ -174,6 +154,7 @@ class ConceptScheme(ItemScheme):
                  version: str = None, validFrom: datetime = None,
                  validTo: datetime = None,
                  isFinal: bool = None, isExternalReference: bool = None,
+                 isPartial: bool = None,
                  serviceUrl: str = None,
                  structureUrl: str = None, maintainer=None,
                  items=None):
@@ -189,6 +170,7 @@ class ConceptScheme(ItemScheme):
                      validTo=validTo,
                      isFinal=isFinal,
                      isExternalReference=isExternalReference,
+                     isPartial=isPartial,
                      serviceUrl=serviceUrl,
                      structureUrl=structureUrl,
                      maintainer=maintainer,
@@ -201,41 +183,16 @@ class ConceptScheme(ItemScheme):
             if not self._checked:
                 self._checked = True
                 return super(ConceptScheme, self).__eq__(other)
-            else:
-                return True
-        else:
-            return False
 
-    @staticmethod
-    def _factory(*args_, **kwargs_):
-        """Factory Method of ConceptScheme"""
-        return ConceptScheme(*args_, **kwargs_)
+            return True
+
+        return False
 
     @property
     def cl_references(self):
         """For parsing purposes, makes a dict of all the Codelist references"""
         return self._cl_references
 
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        super(ConceptScheme, self)._build_attributes(node, attrs,
-                                                     already_processed)
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        super(ConceptScheme, self)._build_children(child_, node, nodeName_,
-                                                   fromsubclass_,
-                                                   gds_collector_)
-        if nodeName_ == 'Concept':
-            obj_ = Concept._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            if (obj_.core_representation is not None and
-                    obj_.core_representation.codelist is not None):
-                self._cl_references[
-                    obj_.id] = obj_.core_representation.codelist
-            self.append(obj_)
-
 
 class Codelist(ItemScheme):
     """ A list from which some statistical concepts (coded concepts) take
@@ -253,6 +210,7 @@ class Codelist(ItemScheme):
                  version: str = None, validFrom: datetime = None,
                  validTo: datetime = None,
                  isFinal: bool = None, isExternalReference: bool = None,
+                 isPartial: bool = None,
                  serviceUrl: str = None,
                  structureUrl: str = None, maintainer=None,
                  items=None):
@@ -266,6 +224,7 @@ class Codelist(ItemScheme):
                                        serviceUrl=serviceUrl,
                                        structureUrl=structureUrl,
                                        maintainer=maintainer,
+                                       isPartial=isPartial,
                                        items=items)
         self._checked = False
 
@@ -274,10 +233,10 @@ class Codelist(ItemScheme):
             if not self._checked:
                 self._checked = True
                 return super(Codelist, self).__eq__(other)
-            else:
-                return True
-        else:
-            return False
+
+            return True
+
+        return False
 
     def __str__(self):
         return f'<{self.__class__.__name__} - {self.id}>'
@@ -288,26 +247,6 @@ class Codelist(ItemScheme):
     def __repr__(self):
         return f'<{self.__class__.__name__} - {self.id}>'
 
-    @staticmethod
-    def _factory(*args_, **kwargs_):
-        """Factory Method of Codelist"""
-        return Codelist(*args_, **kwargs_)
-
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        super(Codelist, self)._build_attributes(node, attrs, already_processed)
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        super(Codelist, self)._build_children(child_, node, nodeName_,
-                                              fromsubclass_, gds_collector_)
-
-        if nodeName_ == 'Code':
-            obj_ = Code._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            self.append(obj_)
-
 
 class OrganisationScheme(ItemScheme):
     """Abstract class. Used for structure messages"""
@@ -318,9 +257,12 @@ class OrganisationScheme(ItemScheme):
                  description: InternationalString = None,
                  version: str = None, validFrom: datetime = None,
                  validTo: datetime = None,
-                 isFinal: bool = None, isExternalReference: bool = None,
+                 isFinal: bool = None,
+                 isExternalReference: bool = None,
+                 isPartial: bool = None,
                  serviceUrl: str = None,
-                 structureUrl: str = None, maintainer=None,
+                 structureUrl: str = None,
+                 maintainer=None,
                  items=None):
 
         super(OrganisationScheme, self). \
@@ -333,6 +275,7 @@ class OrganisationScheme(ItemScheme):
                      validTo=validTo,
                      isFinal=isFinal,
                      isExternalReference=isExternalReference,
+                     isPartial=isPartial,
                      serviceUrl=serviceUrl,
                      structureUrl=structureUrl,
                      maintainer=maintainer,
@@ -341,8 +284,8 @@ class OrganisationScheme(ItemScheme):
     def __eq__(self, other):
         if isinstance(other, OrganisationScheme):
             return super(OrganisationScheme, self).__eq__(other)
-        else:
-            return False
+
+        return False
 
 
 class AgencyScheme(OrganisationScheme):
@@ -382,29 +325,8 @@ class AgencyScheme(OrganisationScheme):
     def __eq__(self, other):
         if isinstance(other, AgencyScheme):
             return super(AgencyScheme, self).__eq__(other)
-        else:
-            return False
 
-    @staticmethod
-    def _factory(*args_, **kwargs_):
-        """Factory Method of AgencyScheme"""
-        return AgencyScheme(*args_, **kwargs_)
-
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        super(AgencyScheme, self)._build_attributes(node, attrs,
-                                                    already_processed)
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        super(AgencyScheme, self)._build_children(child_, node, nodeName_,
-                                                  fromsubclass_,
-                                                  gds_collector_)
-        if nodeName_ == 'Agency':
-            obj_ = Agency._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            self.append(obj_)
+        return False
 
 
 class Item(NameableArtefact):
@@ -445,8 +367,8 @@ class Item(NameableArtefact):
     def __eq__(self, other):
         if isinstance(other, Item):
             return super(Item, self).__eq__(other)
-        else:
-            return False
+
+        return False
 
     def __str__(self):
         return f'<{self.__class__.__name__} - {self.id}>'
@@ -486,37 +408,11 @@ class Item(NameableArtefact):
     @parent.setter
     def parent(self, value):
         self._parent = value
-        """
-        if value is None:
-            self._parent = value
-        elif value.__class__ == self.__class__:
-            value.addChild(self)
-            self._parent = value
-        else:
-            raise TypeError(f"The parent of a {self._schemeType} has to be "
-                            f"another {self._schemeType}  object")
-        """
 
     def add_child(self, value):
         """Adds a child to the Item"""
         self._childs.append(value)
 
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        super(Item, self)._build_attributes(node, attrs, already_processed)
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=None,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        super(Item, self). \
-            _build_children(child_, node, nodeName_,
-                            fromsubclass_, gds_collector_)
-
-        if nodeName_ == 'Parent':
-            obj_ = RelationshipRefType._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            self.parent = obj_.ref
-
     def _parse_XML(self, indent, head):
         head = f'{structureAbbr}:' + head
 
@@ -526,6 +422,16 @@ class Item(NameableArtefact):
         indent = add_indent(indent)
         outfile = f'{indent}<{head}{data["Attributes"]}>'
         outfile += export_intern_data(data, indent)
+        if self.parent is not None:
+            indent_par = add_indent(indent)
+            indent_ref = add_indent(indent_par)
+            outfile += f'{indent_par}<{structureAbbr}:Parent>'
+            if isinstance(self.parent, Item):
+                text = self.parent.id
+            else:
+                text = self.parent
+            outfile += f'{indent_ref}<Ref id="{text}"/>'
+            outfile += f'{indent_par}</{structureAbbr}:Parent>'
         return outfile
 
 
@@ -557,23 +463,8 @@ class Code(Item):
     def __eq__(self, other):
         if isinstance(other, Code):
             return super(Code, self).__eq__(other)
-        else:
-            return False
 
-    @staticmethod
-    def _factory(*args_, **kwargs_):
-        """Factory Method of Code"""
-        return Code(*args_, **kwargs_)
-
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        super(Code, self)._build_attributes(node, attrs, already_processed)
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=None,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        super(Code, self)._build_children(child_, node, nodeName_,
-                                          fromsubclass_, gds_collector_)
+        return False
 
     def _parse_XML(self, indent, head):
         outfile = super(Code, self)._parse_XML(indent, head)
@@ -612,8 +503,8 @@ class Agency(Item):
         if isinstance(other, Agency):
             return super(Agency, self).__eq__(
                 other) and self._contacts == other._contacts
-        else:
-            return False
+
+        return False
 
     @property
     def contacts(self):
@@ -624,28 +515,6 @@ class Agency(Item):
     def contacts(self, value):
         self._contacts = generic_setter(value, List[Contact])
 
-    @staticmethod
-    def _factory(*args_, **kwargs_):
-        """Factory Method of Agency"""
-        return Agency(*args_, **kwargs_)
-
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        super(Agency, self)._build_attributes(node, attrs, already_processed)
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        super(Agency, self)._build_children(child_, node, nodeName_,
-                                            fromsubclass_, gds_collector_)
-
-        if nodeName_ == 'Contact':
-            obj_ = Contact._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            if self._contacts is None:
-                self._contacts = []
-            self._contacts.append(obj_)
-
     def _parse_XML(self, indent, head):
         outfile = super(Agency, self)._parse_XML(indent, head)
 
@@ -678,7 +547,7 @@ class Concept(Item):
                  name: InternationalString = None,
                  description: InternationalString = None,
                  scheme: ItemScheme = None, parent: Item = None, childs=None,
-                 coreRepresentation: Representation = None):
+                 core_representation: Representation = None):
         if childs is None:
             childs = []
         if annotations is None:
@@ -689,15 +558,15 @@ class Concept(Item):
                                       scheme=scheme, parent=parent,
                                       childs=childs)
 
-        self.core_representation = coreRepresentation
+        self.core_representation = core_representation
         self._ref = None  # Attribute for storing the references to codelists.
 
     def __eq__(self, other):
         if isinstance(other, Concept):
             return (super(Concept, self).__eq__(other) and
                     self._coreRepresentation == other._coreRepresentation)
-        else:
-            return False
+
+        return False
 
     @property
     def core_representation(self):
@@ -709,25 +578,6 @@ class Concept(Item):
         from .representation import Representation
         self._coreRepresentation = generic_setter(value, Representation)
 
-    @staticmethod
-    def _factory(*args_, **kwargs_):
-        """Factory Method of Concept"""
-        return Concept(*args_, **kwargs_)
-
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        super(Concept, self)._build_attributes(node, attrs, already_processed)
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=None,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        super(Concept, self)._build_children(child_, node, nodeName_,
-                                             fromsubclass_, gds_collector_)
-        if nodeName_ == 'CoreRepresentation':
-            obj_ = Representation._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            self.core_representation = obj_
-
     def _parse_XML(self, indent, head):
         outfile = super(Concept, self)._parse_XML(indent, head)
 
@@ -758,7 +608,21 @@ class Concept(Item):
                                f'version="{version}" class="Codelist"/>'
 
                 outfile += f'{indent_enum}</{structureAbbr}:Enumeration>'
+            else:
+                label_format = "TextFormat"
+                format_attributes = ' '
 
+                if self.core_representation.type_ is not None:
+                    format_attributes = f' textType=' \
+                                        f'"{self.core_representation.type_}"'
+
+                if self.core_representation.facets is not None:
+                    for e in self.core_representation.facets:
+                        format_attributes += f' {e.facet_type}=' \
+                                             f'"{e.facet_value}"'
+
+                outfile += f'{indent_enum}<{structureAbbr}:' \
+                           f'{label_format}{format_attributes}/>'
             outfile += f'{indent_child}</{structureAbbr}:CoreRepresentation>'
 
         outfile += f'{indent}</{structureAbbr}:{head}>'
